Method: Polyphony.backend_timeout
- Defined in:
- ext/polyphony/polyphony.c
.backend_timeout(duration) ⇒ any .backend_timeout(duration, exception_class) ⇒ any
Runs the given block, raising an exception if the block has not finished running before a timeout has elapsed, using the given duration. If an exception class is not given, a TimeoutError is raised.
292 293 294 |
# File 'ext/polyphony/polyphony.c', line 292 VALUE Polyphony_backend_timeout(int argc,VALUE *argv, VALUE self) { return Backend_timeout(argc, argv, BACKEND()); } |